Document structure support for the Oak language framework.
This crate provides traits and structures for representing the hierarchical structure of a document, such as for an outline view or breadcrumbs.
Structs
- Structure
Item - Represents an item in the document structure (e.g., in an outline or breadcrumbs).
Traits
- Structure
Provider - Trait for languages that support structure view and navigation.